Palette

Struct Palette 

pub struct Palette<'a> {
    pub index: i32,
    pub overrides: &'a [Override],
}
Specifies a palette to use and overrides for palette entries.

overrides is a list of pairs of palette entry index and color. Overridden palette entries use the associated color.

Override pairs with palette entry indices out of range are not applied. Later override entries override earlier ones.

Fields

index: i32overrides: &'a [Override]